Detail Perseroan - AHU Online

## Detail Perseroan Terbatas

Nama Perusahaan | PT CONTOH INDONESIA TBK
Nomor Pengesahan | AHU-0012345.AH.01.01.TAHUN2020
Tanggal Pengesahan | 15-03-2020
Bentuk Badan Usaha | Perseroan Terbatas (PT)
Status Perusahaan | AKTIF
Domisili | Jl. Sudirman Kav. 52-53, Jakarta Pusat, DKI Jakarta
Kegiatan Usaha | Perdagangan besar berbasis web (e-commerce)
Modal Dasar | Rp 10.000.000.000
Modal Disetor | Rp 2.500.000.000

### Direksi

Nama | Jabatan | NPWP
--- | --- | ---
BUDI SANTOSO | Direktur Utama | 12.345.678.9-001.000
SARI DEWI | Direktur | 98.765.432.1-001.000

### Dewan Komisaris

Nama | Jabatan
--- | ---
AHMAD YUSUF | Komisaris Utama
LINDA HALIM | Komisaris